apiVersion: v1
kind: Service
spec:
  ports:
    - port: {{ keystone_admin_port }}
      name: keystone-admin
  selector:
    service: keystone
    type: api
metadata:
   name: keystone-admin
   namespace: {{ kolla_kubernetes_namespace }}
