{
    "command": "glance-registry",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/glance-registry.conf",
            "dest": "/etc/glance/glance-registry.conf",
            "owner": "glance",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/policy.json",
            "dest": "/etc/glance/policy.json",
            "owner": "glance",
            "perm": "0600",
            "optional": true
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/glance",
            "owner": "glance:glance",
            "recurse": true
        }
    ]
}
