function common_iscsi_config {
    echo "global:"
    echo "  kolla:"
    echo "    all:"
    echo "      image_tag: 4.0.0"
    echo "      storage_provider: host"
    echo "      install_type: source"
    echo "      storage_provider_fstype: xfs"
    echo "      ceph_backend: false"
    echo "      lvm_backends:"
    echo "      - '172.18.0.1': 'cinder-volumes'"
    echo "    cinder:"
    echo "      all:"
    echo "        image_tag: 4.0.0"
    echo "      volume_lvm:"
    echo "        all:"
    echo "          element_name: cinder-volume"
    echo "    nova:"
    echo "      all:"
    echo "        image_tag: 4.0.0"
    echo "    ironic:"
    echo "      all:"
    echo "        image_tag: 4.0.0"
    echo "      conductor:"
    echo "        all:"
    echo "          initramfs_url: http://tarballs.openstack.org/ironic-python-agent/tinyipa/files/tinyipa-stable-newton.gz"
    echo "          kernel_url: http://tarballs.openstack.org/ironic-python-agent/tinyipa/files/tinyipa-stable-newton.vmlinuz"
    echo "          ironic_api_ip: 172.21.0.10"
    echo "          ironic_tftp_server: 172.21.0.10"
    echo "      dnsmasq:"
    echo "        all:"
    echo "          initramfs_url: http://tarballs.openstack.org/ironic-python-agent/tinyipa/files/tinyipa-stable-newton.gz"
    echo "          kernel_url: http://tarballs.openstack.org/ironic-python-agent/tinyipa/files/tinyipa-stable-newton.vmlinuz"
    echo "          ironic_dhcp_range: net2,172.22.0.10,172.22.0.20,255.255.255.0,24h"
    echo "    horizon:"
    echo "      all:"
    echo "        image_tag: 4.0.0"
}
