{%- macro secret() -%}
<secret ephemeral='no' private='no'>
  <uuid>{{ rbd_secret_uuid }}</uuid>
  <usage type='ceph'>
    <name>client.nova secret</name>
  </usage>
</secret>
{%- endmacro %}
apiVersion: v1
kind: Secret
type: Opaque
metadata:
  name: nova-libvirt
  namespace: {{ kolla_kubernetes_namespace }}
data:
  data: {{ secret() | b64encode }}
