{
    "command": "/usr/sbin/in.tftpd --verbose --foreground --user root --address 0.0.0.0:69 --map-file /map-file /tftpboot",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/default",
            "dest": "/tftpboot/pxelinux.cfg/default",
            "owner": "root",
            "perm": "0644"
        }
    ]
}
