apiVersion: v1
kind: Service
spec:
  ports:
    - port: {{ mariadb_port }}
      name: mariadb
  selector:
    service: mariadb
metadata:
   name: mariadb
   namespace: {{ kolla_kubernetes_namespace }}
