[DEFAULT]
debug = {{ keystone_logging_debug }}
{% if enable_cadf_notifications | bool %}
notification_format = cadf
transport_url = rabbit://{{ rabbitmq_user }}:{{ rabbitmq_password }}@rabbitmq:{{ rabbitmq_port }}
{% endif %}

# NOTE(elemoine) log_dir alone does not work for Keystone
log_file = /var/log/kolla/keystone/keystone.log
use_stderr = True

secure_proxy_ssl_header = HTTP_X_FORWARDED_PROTO

[database]
connection = mysql+pymysql://{{ keystone_database_user }}:{{ keystone_database_password }}@{{ keystone_database_address }}/{{ keystone_database_name }}
max_retries = -1

{% if keystone_domain_directory.stat.exists %}
[identity]
domain_specific_drivers_enabled = true
domain_config_dir = /etc/keystone/domains
{% endif %}

[token]
revoke_by_id = False
{% if keystone_token_provider == 'uuid' %}
provider = uuid
{% elif keystone_token_provider == 'fernet' %}
provider = {{ keystone_token_provider }}
expiration = {{ fernet_token_expiry }}

[fernet_tokens]
max_active_keys = 3
{% endif %}

[cache]
backend = oslo_cache.memcache_pool
enabled = True

{# For Kolla-Ansible, generate the memcache servers based on the list of
memcached servers in the inventory and memcached_servers should be un-set.
For Kolla-Kubernetes,  it is necessary to define the memcached_servers
variable in globals.yml to set it to the Kubernetes service for memcached. #}

memcache_servers = {{ memcached_servers }}:{{ memcached_port }}

{% if enable_cadf_notifications | bool %}
[oslo_messaging_notifications]
driver = messagingv2
{% endif %}
