[global]
log file = /var/log/kolla/ceph/$cluster-$name.log
log to syslog = false
err to syslog = false
log to stderr = false
err to stderr = false

fsid = {{ ceph_cluster_fsid }}

auth cluster required = cephx
auth service required = cephx
auth client required = cephx

# NOTE(inc0): This line will mean that if ceph was upgraded, it will run as root
#             until contents of /var/lib/ceph are chowned to ceph user.
#             This change was introduced in Jewel version and we should include
#             chown operation in upgrade procedure. https://bugs.launchpad.net/kolla/+bug/1620702
setuser match path = /var/lib/ceph/$type/$cluster-$id

[mon]
# NOTE(SamYaple): The monitor files have been known to grow very large. The
#                 only fix for that is to compact the files.
mon compact on start = true
mon cluster log file = /var/log/kolla/ceph/$cluster.log

{% if service_name is defined and service_name == 'ceph-rgw' %}
[client.radosgw.gateway]
{% if enable_ceph_rgw_keystone | bool %}
rgw_keystone_url = {{ admin_protocol }}://{{ kolla_internal_fqdn }}:{{ keystone_admin_port }}
rgw_keystone_admin_user = {{ openstack_auth.username }}
rgw_keystone_admin_password = {{ openstack_auth.password }}
rgw_keystone_admin_project = {{ openstack_auth.project_name }}
rgw_keystone_admin_domain = default
rgw_keystone_api_version = 3
rgw_keystone_accepted_roles = admin, {{ keystone_default_user_role }}
{% endif %}
keyring = /etc/ceph/ceph.client.radosgw.keyring
log file = /var/log/kolla/ceph/client.radosgw.gateway.log
{% endif %}
