port=0
interface={{ api_interface }}
dhcp-range={{ ironic_dnsmasq_dhcp_range }}
dhcp-option=option:tftp-server,{{ kolla_internal_vip_address }}
dhcp-option=option:server-ip-address,{{ kolla_internal_vip_address }}
bind-interfaces
dhcp-sequential-ip
dhcp-option=option:bootfile-name,pxelinux.0
dhcp-option=210,/tftpboot/
