apiVersion: v1
kind: Service
spec:
  ports:
    - port: {{ swift_account_server_port }}
  selector:
    name: swift-account
metadata:
   name: swift-account
   namespace: {{ kolla_kubernetes_namespace }}
