apiVersion: v1
kind: Service
spec:
  ports:
    - port: {{ rabbitmq_port }}
      name: rabbitmq
  selector:
    service: rabbitmq
metadata:
   name: rabbitmq
   namespace: {{ kolla_kubernetes_namespace }}
